'use strict';

var AST = require("./aST.bs.js");
var List = require("bs-platform/lib/js/list.js");
var $$Array = require("bs-platform/lib/js/array.js");
var Block = require("bs-platform/lib/js/block.js");
var Curry = require("bs-platform/lib/js/curry.js");
var $$String = require("bs-platform/lib/js/string.js");
var MenhirLib = require("./menhirLib.bs.js");
var Pervasives = require("bs-platform/lib/js/pervasives.js");
var Caml_string = require("bs-platform/lib/js/caml_string.js");
var Caml_exceptions = require("bs-platform/lib/js/caml_exceptions.js");
var Caml_builtin_exceptions = require("bs-platform/lib/js/caml_builtin_exceptions.js");

var $$Error = Caml_exceptions.create("ParserAutomaton.MenhirBasics.Error");

function token2terminal(_tok) {
  if (typeof _tok === "number") {
    switch (_tok) {
      case 0 : 
          return 3;
      case 1 : 
          return 8;
      case 2 : 
          return 9;
      case 3 : 
          return 10;
      case 4 : 
          return 12;
      case 5 : 
          return 13;
      case 6 : 
          return 21;
      case 7 : 
          return 22;
      case 8 : 
          return 24;
      case 9 : 
          return 25;
      case 10 : 
          return 27;
      case 11 : 
          return 28;
      
    }
  } else {
    switch (_tok.tag | 0) {
      case 0 : 
          return 1;
      case 1 : 
          return 2;
      case 2 : 
          return 4;
      case 3 : 
          return 5;
      case 4 : 
          return 6;
      case 5 : 
          return 7;
      case 6 : 
          return 11;
      case 7 : 
          return 14;
      case 8 : 
          return 15;
      case 9 : 
          return 16;
      case 10 : 
          return 17;
      case 11 : 
          return 18;
      case 12 : 
          return 19;
      case 13 : 
          return 20;
      case 14 : 
          return 23;
      case 15 : 
          return 26;
      
    }
  }
}

function token2value(_tok) {
  if (typeof _tok === "number") {
    return /* () */0;
  } else {
    return _tok[0];
  }
}

var default_reduction = /* tuple */[
  8,
  "\0\0\x0f\f\0\x18\0-\0\0\0\r6\b\n\x000!\x1f /\x00321.\t\0\0\x13\x12\0\x03\x04\0\x05\x06\x14\x16%\0'&5\0\0\x15\x11\0)\0*7($\0\x07\0\x0b\x1a\x01\0\x02\x1c\x004\x1b\0\x1d\0\x1e"
];

var error = /* tuple */[
  29,
  "\bP\x01\x10B\x80\b\x80\0\0\0\0\0\0\0\x85\0\x10\0\0\0\0!@\0\0\0\0\0\bP\x01\x10\x05\0\0\x02\x14\0D\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x01\xe0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x07\x80\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\xb1\xf8\x04\x12\0\0\0\0\0\0\0\0\0\0\x01\x02\0\0\0\0\0\0\0\0\0\x02\x04\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x10\xac\x02\0\0\0\0\0\0\0\0\0\0\0\x05\x8f\xc0`\xa4(\0\x04\0\0\0\0\0\0\0X\xfc\x02\b\0\0\0\x16?\0\x82\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x02\x10\0@\0\0\0\0\0\0\x10\0\0\0\0\0\0\0\0\0\0\0\f(\x01\x88\0\0\0\0\0\0\0\0\0\x02\0\0\0\0\0\0\0\0!\0\x04\0\0\0\0\x04(\x01\x88\0\0\0\0"
];

var action = /* tuple */[
  /* tuple */[
    8,
    "\x96\x96\0\0\xce\0j\0\x96\t\x96\0\0\0\0\x12\0\0\0\0\0>\0\0\0\0\0*\x03\0\0\x1e\0\0J\0\0\0\0\0\xba\0\0\0\x03*\0\0V\0\x82\0\0\0\0(\0#\0\0\0\x9a\0\0\x0b\0\0(\0\x96\0"
  ],
  /* tuple */[
    16,
    "\0=\0v\0=\0=\0*\0\xeb\x002\0=\0=\0=\0=\0=\0=\0B\0F\0J\0N\x01\x07\0\0\0\x1e\0\xb6\0=\0r\0\xe2\0\x85\0\x1e\0\x82\0=\0*\0\x85\0\"\0\x85\0z\0~\0\x8a\0B\0F\0Z\0N\0\0\0\0\0\x1e\0a\0\x85\0r\0\0\0\xad\0\x1e\0\x8e\0\x96\0\0\0\xad\0\"\0\xad\0z\0\xad\0\xad\0\x1e\0\0\0\0\0\0\0\0\0\"\0\0\x006\0\xad\0r\0\0\0\xa9\0\x1e\0\0\0\x96\0\0\0\xa9\0\"\0\xa9\0z\0\xa9\0\xa9\x005\0\xe2\x005\0\0\0\0\x005\0\0\x005\0\xa9\x005\0\0\0\0\0\0\0\0\0\x96\0\0\0\0\0\x89\0e\x005\0a\x005\0\x89\0\x06\0\x89\0\x06\0~\0\x8a\0Y\0\0\0\0\0\0\0\0\0Y\0\0\0Y\0\x89\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\0\x16"
  ]
];

var lhs = /* tuple */[
  8,
  "\x01\0\x1b\x1b\x1a\x1a\x19\x18\x18\x18\x17\x16\x16\x15\x15\x14\x14\x13\x13\x13\x13\x13\x12\x12\x11\x11\x10\x10\x0f\x0f\x0e\r\r\f\f\x0b\x0b\x0b\x0b\n\n\n\t\t\b\b\b\x07\x07\x07\x06\x05\x04\x03\x02"
];

var $$goto = /* tuple */[
  /* tuple */[
    8,
    " \x0e\0\0\x18\x004\0\0\0\x18\0\0\0\0\x07\0\0\0\0\0n\0\0\0\0\0\x07\0\0\0\n\0\0J\0\0\0\0\0 \0\0\0\0L\0\0R\0Z\0\0\0\0R\0\0\0\0\0\x14\0\0\0\0\0\\\0h\0"
  ],
  /* tuple */[
    8,
    "'(\x04\x15\x16\x10)135\x1a/\x04\x10\f?67\x04\"*\x05\n,-@AC\x03\x0f\x07\x05D\x05\x10<+\x058=\x1b',-'\x10\x10\0'\x10\x1c%/\x10\x04/\x000:/2\x18\x16E4\0<G\x19\0\0F\0\x05D"
  ]
];

var semantic_action = /* array */[
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : () */0,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */Block.__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */Block.__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Sub */Block.__(0, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */match[/* semv */1],
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      var _v = AST.pipe_last(match[/* semv */1], _menhir_stack[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv : [] */0,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = match[/* semv */1];
      var _v_001 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Flag */Block.__(1, [/* record */[
            /* name */_menhir_stack[/* semv */1],
            /* payload : Absent */1
          ]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      var _v = /* Flag */Block.__(1, [/* record */[
            /* name */match[/* semv */1],
            /* payload : Resolved */[_menhir_stack[/* semv */1]]
          ]]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */Block.__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = /* Literal */Block.__(1, [match[/* semv */1] + _menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : Literal */Block.__(1, ["--"]),
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Literal */Block.__(1, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = /* Sub */Block.__(0, [_menhir_stack[/* semv */1]]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv */undefined,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = _menhir_stack[/* semv */1];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv */undefined,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = _menhir_stack[/* semv */1];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : [] */0,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4][/* next */4];
      var _v_000 = match[/* semv */1];
      var _v_001 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = $$String.concat("", List.rev(match[/* semv */1]));
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _menhir_s = _menhir_env[/* current */3];
      var _startpos = _menhir_stack[/* endp */3];
      return /* record */[
              /* state */_menhir_s,
              /* semv : [] */0,
              /* startp */_startpos,
              /* endp */_startpos,
              /* next */_menhir_stack
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v = List.rev(_menhir_stack[/* semv */1]);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = List.rev_append(_menhir_stack[/* semv */1], match[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v_000 = /* Positional */Block.__(0, [_menhir_stack[/* semv */1]]);
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = /* Positional */Block.__(0, [_menhir_stack[/* semv */1]]);
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var xs = match[/* semv */1];
      var pos = /* Positional */Block.__(0, [_menhir_stack[/* semv */1]]);
      var _v;
      if (xs) {
        var arg = xs[0];
        if (arg.tag) {
          var flag = arg[0];
          var match$1 = flag[/* payload */1];
          _v = typeof match$1 === "number" ? (
              match$1 !== 0 ? /* :: */[
                  pos,
                  /* :: */[
                    /* Flag */Block.__(1, [/* record */[
                          /* name */flag[/* name */0],
                          /* payload : Unresolved */0
                        ]]),
                    xs[1]
                  ]
                ] : Pervasives.failwith("unreachable: rev_arguments_and_positional, unresolved")
            ) : /* :: */[
              pos,
              xs
            ];
        } else {
          _v = Pervasives.failwith("unreachable: rev_arguments_and_positional, positional");
        }
      } else {
        _v = Pervasives.failwith("unreachable: rev_arguments_and_positional, empty xs");
      }
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_menhir_stack[/* semv */1],
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv : [] */0,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = Pervasives.$at(_menhir_stack[/* semv */1], match[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v = /* :: */[
        _v_000,
        /* [] */0
      ];
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = Pervasives.$at(_menhir_stack[/* semv */1], match[/* semv */1]);
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v_000 = _menhir_stack[/* semv */1];
      var _v_001 = match[/* semv */1];
      var _v = /* :: */[
        _v_000,
        _v_001
      ];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var _v = /* record */[/* expressions */$$Array.of_list(match[/* semv */1])];
      return /* record */[
              /* state */match[/* state */0],
              /* semv */_v,
              /* startp */match[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var explode = function (str) {
        var last = str.length - 1 | 0;
        if (str === "") {
          return /* [] */0;
        } else {
          return /* :: */[
                  $$String.make(1, Caml_string.get(str, 0)),
                  explode($$String.sub(str, 1, last))
                ];
        }
      };
      var xs = explode(_menhir_stack[/* semv */1]);
      var _v = List.map((function (x) {
              return /* Flag */Block.__(1, [/* record */[
                          /* name */x,
                          /* payload : Absent */1
                        ]]);
            }), xs);
      return /* record */[
              /* state */_menhir_stack[/* state */0],
              /* semv */_v,
              /* startp */_menhir_stack[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */_menhir_stack[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var match$1 = match[/* next */4];
      return /* record */[
              /* state */match$1[/* state */0],
              /* semv */match[/* semv */1],
              /* startp */match$1[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match$1[/* next */4]
            ];
    }),
  (function (_menhir_env) {
      var _menhir_stack = _menhir_env[/* stack */2];
      var match = _menhir_stack[/* next */4];
      var match$1 = match[/* next */4];
      var match$2 = match$1[/* next */4];
      var _v = AST.make_expression(match$1[/* semv */1], match[/* semv */1], _menhir_stack[/* semv */1]);
      return /* record */[
              /* state */match$2[/* state */0],
              /* semv */_v,
              /* startp */match$2[/* startp */2],
              /* endp */_menhir_stack[/* endp */3],
              /* next */match$2[/* next */4]
            ];
    })
];

var ET = MenhirLib.TableInterpreter[/* MakeEngineTable */0]([
      token2terminal,
      0,
      token2value,
      default_reduction,
      error,
      action,
      lhs,
      $$goto,
      2,
      semantic_action,
      $$Error,
      undefined
    ]);

var TI = MenhirLib.Engine[/* Make */0](ET);

var entry = TI[1];

var start = TI[25];

var Symbols = /* module */[];

MenhirLib.InspectionTableInterpreter[/* Symbols */0](Symbols);

function terminal(t) {
  switch (t) {
    case 0 : 
        return /* X */[/* T */Block.__(0, [/* T_error */0])];
    case 1 : 
        return /* X */[/* T */Block.__(0, [/* T_URL_START */1])];
    case 2 : 
        return /* X */[/* T */Block.__(0, [/* T_URL_REST */2])];
    case 3 : 
        return /* X */[/* T */Block.__(0, [/* T_SEMICOLON */3])];
    case 4 : 
        return /* X */[/* T */Block.__(0, [/* T_QUOTE_OPEN */4])];
    case 5 : 
        return /* X */[/* T */Block.__(0, [/* T_QUOTE_ESCAPE */5])];
    case 6 : 
        return /* X */[/* T */Block.__(0, [/* T_QUOTE_CLOSE */6])];
    case 7 : 
        return /* X */[/* T */Block.__(0, [/* T_QUOTE_CHUNK */7])];
    case 8 : 
        return /* X */[/* T */Block.__(0, [/* T_PIPE */8])];
    case 9 : 
        return /* X */[/* T */Block.__(0, [/* T_PAREN_OPEN */9])];
    case 10 : 
        return /* X */[/* T */Block.__(0, [/* T_PAREN_CLOSE */10])];
    case 11 : 
        return /* X */[/* T */Block.__(0, [/* T_IDENTIFIER */11])];
    case 12 : 
        return /* X */[/* T */Block.__(0, [/* T_FLAG_LONG_START */12])];
    case 13 : 
        return /* X */[/* T */Block.__(0, [/* T_FLAGS_SHORT_START */13])];
    case 14 : 
        return /* X */[/* T */Block.__(0, [/* T_ERR_UNEXPECTED_WHITESPACE */14])];
    case 15 : 
        return /* X */[/* T */Block.__(0, [/* T_ERR_UNEXPECTED_QUOTE_ESCAPE */15])];
    case 16 : 
        return /* X */[/* T */Block.__(0, [/* T_ERR_UNEXPECTED_QUOTE_CLOSE */16])];
    case 17 : 
        return /* X */[/* T */Block.__(0, [/* T_ERR_UNEXPECTED_COMMENT_CLOSE */17])];
    case 18 : 
        return /* X */[/* T */Block.__(0, [/* T_ERR_UNEXPECTED_CHARACTER */18])];
    case 19 : 
        return /* X */[/* T */Block.__(0, [/* T_ERR_MISSING_DELIM_CLOSE */19])];
    case 20 : 
        return /* X */[/* T */Block.__(0, [/* T_ERR_MISSING_COMMENT_CLOSE */20])];
    case 21 : 
        return /* X */[/* T */Block.__(0, [/* T_EQUALS */21])];
    case 22 : 
        return /* X */[/* T */Block.__(0, [/* T_EOF */22])];
    case 23 : 
        return /* X */[/* T */Block.__(0, [/* T_COUNT */23])];
    case 24 : 
        return /* X */[/* T */Block.__(0, [/* T_COMMENT_OPEN */24])];
    case 25 : 
        return /* X */[/* T */Block.__(0, [/* T_COMMENT_CLOSE */25])];
    case 26 : 
        return /* X */[/* T */Block.__(0, [/* T_COMMENT */26])];
    case 27 : 
        return /* X */[/* T */Block.__(0, [/* T_COLON */27])];
    case 28 : 
        return /* X */[/* T */Block.__(0, [/* T_BARE_DOUBLE_DASH */28])];
    default:
      throw [
            Caml_builtin_exceptions.assert_failure,
            /* tuple */[
              "parserAutomaton.ml",
              2416,
              12
            ]
          ];
  }
}

function nonterminal(nt) {
  switch (nt) {
    case 2 : 
        return /* X */[/* N */Block.__(1, [/* N_unterminated_expression */0])];
    case 3 : 
        return /* X */[/* N */Block.__(1, [/* N_subexpression */1])];
    case 4 : 
        return /* X */[/* N */Block.__(1, [/* N_short_flags */2])];
    case 5 : 
        return /* X */[/* N */Block.__(1, [/* N_script */3])];
    case 6 : 
        return /* X */[/* N */Block.__(1, [/* N_rev_subquotation */4])];
    case 7 : 
        return /* X */[/* N */Block.__(1, [/* N_rev_nonempty_subquotation */5])];
    case 8 : 
        return /* X */[/* N */Block.__(1, [/* N_rev_nonempty_quotation */6])];
    case 9 : 
        return /* X */[/* N */Block.__(1, [/* N_rev_arguments_nonempty */7])];
    case 10 : 
        return /* X */[/* N */Block.__(1, [/* N_rev_arguments_and_positional */8])];
    case 11 : 
        return /* X */[/* N */Block.__(1, [/* N_rev_arguments_and_flag */9])];
    case 12 : 
        return /* X */[/* N */Block.__(1, [/* N_rev_arguments */10])];
    case 13 : 
        return /* X */[/* N */Block.__(1, [/* N_quotation_chunk */11])];
    case 14 : 
        return /* X */[/* N */Block.__(1, [/* N_quotation */12])];
    case 15 : 
        return /* X */[/* N */Block.__(1, [/* N_optterm_nonempty_list_break_expression_chain_ */13])];
    case 16 : 
        return /* X */[/* N */Block.__(1, [/* N_optterm_list_break_expression_chain_ */14])];
    case 17 : 
        return /* X */[/* N */Block.__(1, [/* N_option_break_ */15])];
    case 18 : 
        return /* X */[/* N */Block.__(1, [/* N_option_COUNT_ */16])];
    case 19 : 
        return /* X */[/* N */Block.__(1, [/* N_noncommand_word */17])];
    case 20 : 
        return /* X */[/* N */Block.__(1, [/* N_long_flag */18])];
    case 21 : 
        return /* X */[/* N */Block.__(1, [/* N_list_COLON_ */19])];
    case 22 : 
        return /* X */[/* N */Block.__(1, [/* N_expression_chain */20])];
    case 23 : 
        return /* X */[/* N */Block.__(1, [/* N_expression */21])];
    case 24 : 
        return /* X */[/* N */Block.__(1, [/* N_command */22])];
    case 25 : 
        return /* X */[/* N */Block.__(1, [/* N_break */23])];
    case 26 : 
        return /* X */[/* N */Block.__(1, [/* N__flags_short */24])];
    case 27 : 
        return /* X */[/* N */Block.__(1, [/* N__flag_long */25])];
    default:
      throw [
            Caml_builtin_exceptions.assert_failure,
            /* tuple */[
              "parserAutomaton.ml",
              2474,
              12
            ]
          ];
  }
}

var include = MenhirLib.InspectionTableInterpreter[/* Make */1]([
            token2terminal,
            0,
            token2value,
            default_reduction,
            error,
            action,
            lhs,
            $$goto,
            2,
            semantic_action,
            $$Error,
            undefined
          ])(/* module */[
          /* terminal */terminal,
          /* nonterminal */nonterminal,
          /* rhs : tuple */[
            /* tuple */[
              8,
              "/\x0b\x1a\x18\x1a\x1d\x1c\x18\x1c\x1d\b\x18\x1d\x07-#.\x05-\x12\x058+77,'\x18\x04\x06:\x1d\x0703#\x1f-#-3\x1f\x11\x0e\x10\f\x13)\t\x13)\x13\t'\x15'\x17'\x17\x15\n\x11\x1b\x11\r\n\x0f\x1b\x0f\r\x0f\x0e!.5\x14-\x16+%1\x19"
            ],
            /* tuple */[
              8,
              "\0\x01\x02\x04\x06\b\n\x0b\f\r\x0e\x11\x12\x15\x15\x17\x18\x1b\x1c\x1e\x1f !!\"\"#$%'*,-../013568:;<=?ABDFHJKNR"
            ]
          ],
          /* lr0_core : tuple */[
            8,
            "\0\x01\x02\x03\x04\x05\x06\x07\b\t\n\x0b\f\r\x0e\x0f\x10\x11\x12\x13\x14\x15\x16\x17\x18\x19\x1a\x1b\x1c\x1d\x1e\x1f !\"#$%&'()*+,-./0123456789:;<=>?@ABCDEF"
          ],
          /* lr0_items : tuple */[
            /* tuple */[
              16,
              "\0\0\x07\x01\x07\x02\x05\x81\x1b\x01\x0b\x81\x1b\x02\x16\x01\x1a\x81\x1a\x82\x06\x01\x06\x02\x06\x03\x1a\x83\x03\x81\x04\x81\x17\x01\x16\x81\x0f\x01\x17\x81\x10\x01\x0f\x02\x0f\x81\x17\x02\x19\x01\x18\x81\x18\x01\x19\x02\x18\x82\x18\x02\x16\x82\x04\x01\x1b\x03\t\x01\t\x02\b\x81\x01\x81\x01\x01\x01\x02\x01\x82\x02\x81\x02\x01\x02\x02\x02\x82\t\x81\n\x81\x12\x01\x13\x01\x12\x81\x11\x01\x13\x02\x12\x82\x1a\x01\b\x01\x07\x81\b\x02\n\x01\b\x03\x15\x81\x14\x01\x14\x02\x15\x01\x14\x81\x14\x82\x1b\x04\x13\x81\x11\x81\x06\x01\x05\x01\x03\x01\x05\x02\x05\x03\f\x81\0\x01\0\x80\0\x81\r\x81\x19\x81\x19\x82\r\x01\x0e\x81\x0e\x01\x06\x01\x0e\x02\x0e\x82\f\x81\x0e\x83"
            ],
            /* tuple */[
              8,
              "\0\x01\x02\x03\x04\x05\x06\x07\b\t\x0b\f\r\x0e\x0f\x10\x13\x14\x15\x16\x17\x18\x1b\x1c\x1d\x1e\x1f !\"#$&'(*+,-./2345789:<=?@ABCEFGHIJKLMNOPSTVW"
            ]
          ],
          /* lr0_incoming : tuple */[
            8,
            "\x008+\x05+0%\n\x14-\x12\x05\x16\x18\x07\x11\n\f\x0e\x10\r\x0f\x0e\r\x1b\x1b\x1d1\x04\x06\x18\x1a\x18\x1d\x1c\x18\x1d:\x07\t\x13\t)57,\x1d'\x15'\x17'\x19')-\b#.3/\0\x0b\x1f!.#-#3\x1f"
          ],
          /* nullable */"\0\b\xe4\0",
          /* first : tuple */[
            29,
            "\x18P\x03\x10B\x80\b\x82\x14\0D\0\x80\0\0\0@\0\f(\x01\x88 \0\0\x01\0\0\0\b\0\0\x02B\xe0\0R\x17\0\x02\x90\xb8\0\x14\x85\xc0\0\x82\x80\0\0 \0\0\x01\n\0\"\x18P\x01\x10\x80\0\0\0\0\0@\x90\xa0\0\x10\0\x80\0\0\0\0\b!@\x04A\n\0\"\bP\0\0\x80\0\0\0\x01\0\0\0\x10\0\0"
          ]
        ])(ET)([]);

function script(lexer, lexbuf) {
  return Curry._3(entry, 61, lexer, lexbuf);
}

function expression(lexer, lexbuf) {
  return Curry._3(entry, 0, lexer, lexbuf);
}

function script$1(initial_position) {
  return Curry._2(start, 61, initial_position);
}

function expression$1(initial_position) {
  return Curry._2(start, 0, initial_position);
}

var Incremental = /* module */[
  /* script */script$1,
  /* expression */expression$1
];

var MenhirInterpreter_000 = TI[2];

var MenhirInterpreter_001 = TI[3];

var MenhirInterpreter_002 = TI[4];

var MenhirInterpreter_003 = TI[5];

var MenhirInterpreter_004 = TI[6];

var MenhirInterpreter_005 = TI[7];

var MenhirInterpreter_006 = TI[8];

var MenhirInterpreter_007 = TI[9];

var MenhirInterpreter_008 = TI[10];

var MenhirInterpreter_009 = TI[11];

var MenhirInterpreter_010 = TI[12];

var MenhirInterpreter_011 = TI[13];

var MenhirInterpreter_012 = TI[14];

var MenhirInterpreter_013 = TI[15];

var MenhirInterpreter_014 = TI[16];

var MenhirInterpreter_015 = TI[17];

var MenhirInterpreter_016 = TI[18];

var MenhirInterpreter_017 = TI[19];

var MenhirInterpreter_018 = TI[20];

var MenhirInterpreter_019 = TI[21];

var MenhirInterpreter_020 = TI[22];

var MenhirInterpreter_021 = TI[23];

var MenhirInterpreter_022 = TI[24];

var MenhirInterpreter_023 = include[0];

var MenhirInterpreter_024 = include[1];

var MenhirInterpreter_025 = include[2];

var MenhirInterpreter_026 = include[3];

var MenhirInterpreter_027 = include[4];

var MenhirInterpreter_028 = include[5];

var MenhirInterpreter_029 = include[6];

var MenhirInterpreter_030 = include[7];

var MenhirInterpreter_031 = include[8];

var MenhirInterpreter_032 = include[9];

var MenhirInterpreter_033 = include[10];

var MenhirInterpreter_034 = include[11];

var MenhirInterpreter_035 = include[12];

var MenhirInterpreter_036 = include[13];

var MenhirInterpreter_037 = include[14];

var MenhirInterpreter = [
  MenhirInterpreter_000,
  MenhirInterpreter_001,
  MenhirInterpreter_002,
  MenhirInterpreter_003,
  MenhirInterpreter_004,
  MenhirInterpreter_005,
  MenhirInterpreter_006,
  MenhirInterpreter_007,
  MenhirInterpreter_008,
  MenhirInterpreter_009,
  MenhirInterpreter_010,
  MenhirInterpreter_011,
  MenhirInterpreter_012,
  MenhirInterpreter_013,
  MenhirInterpreter_014,
  MenhirInterpreter_015,
  MenhirInterpreter_016,
  MenhirInterpreter_017,
  MenhirInterpreter_018,
  MenhirInterpreter_019,
  MenhirInterpreter_020,
  MenhirInterpreter_021,
  MenhirInterpreter_022,
  MenhirInterpreter_023,
  MenhirInterpreter_024,
  MenhirInterpreter_025,
  MenhirInterpreter_026,
  MenhirInterpreter_027,
  MenhirInterpreter_028,
  MenhirInterpreter_029,
  MenhirInterpreter_030,
  MenhirInterpreter_031,
  MenhirInterpreter_032,
  MenhirInterpreter_033,
  MenhirInterpreter_034,
  MenhirInterpreter_035,
  MenhirInterpreter_036,
  MenhirInterpreter_037
];

exports.$$Error = $$Error;
exports.script = script;
exports.expression = expression;
exports.MenhirInterpreter = MenhirInterpreter;
exports.Incremental = Incremental;
/* ET Not a pure module */
